@@ -449,7 +449,6 @@ if ($out) {
         require Archive::Zip;
     }
 
-
     my $par = shift(@ARGV);
     my $zip;
 
@@ -516,6 +515,7 @@ if ($out) {
         require PAR::Heavy;
         PAR::Heavy::_init_dynaloader();
         init_inc();
+
         require_modules();
 
         my @inc = sort {
@@ -530,8 +530,13 @@ if ($out) {
 
         if ($Config{_delim} eq '\\') { s{\\}{/}g for @inc }
 
+        # File exists test added to fix RT #41790:
+        # Funny, non-existing entry in _<....auto/Compress/Raw/Zlib/autosplit.ix.
+        # This is a band-aid fix with no deeper grasp of the issue.
+        # Somebody please go through the pain of understanding what's happening,
+        # I failed. -- Steffen
         my %files;
-        /^_<(.+)$/ and $files{$1}++ for keys %::;
+        /^_<(.+)$/ and -e $1 and $files{$1}++ for keys %::;
         $files{$_}++ for values %INC;
 
         my $lib_ext = $Config::Config{lib_ext};
@@ -721,6 +726,7 @@ sub require_modules {
     require vars;
     require Carp;
     require Carp::Heavy;
+    require Errno;
     require Exporter::Heavy;
     require Exporter;
     require Fcntl;
@@ -740,11 +746,13 @@ sub require_modules {
     eval { require Win32 };
     eval { require Scalar::Util };
     eval { require Archive::Unzip::Burst };
+    eval { require Tie::Hash::NamedCapture };
 }
 
 # The C version of this code appears in myldr/mktmpdir.c
+# This code also lives in PAR::SetupTemp as set_par_temp_env!
 sub _set_par_temp {
-    if ($ENV{PAR_TEMP} and $ENV{PAR_TEMP} =~ /(.+)/) {
+    if (defined $ENV{PAR_TEMP} and $ENV{PAR_TEMP} =~ /(.+)/) {
         $par_temp = $1;
         return;
     }
@@ -753,7 +761,7 @@ sub _set_par_temp {
         (map $ENV{$_}, qw( PAR_TMPDIR TMPDIR TEMPDIR TEMP TMP )),
         qw( C:\\TEMP /tmp . )
     ) {
-        next unless $path and -d $path and -w $path;
+        next unless defined $path and -d $path and -w $path;
         my $username;
         my $pwuid;
         # does not work everywhere:
@@ -836,8 +844,9 @@ sub _tempfile {
     return($fh, $filename);
 }
 
+# same code lives in PAR::SetupProgname::set_progname
 sub _set_progname {
-    if ($ENV{PAR_PROGNAME} and $ENV{PAR_PROGNAME} =~ /(.+)/) {
+    if (defined $ENV{PAR_PROGNAME} and $ENV{PAR_PROGNAME} =~ /(.+)/) {
         $progname = $1;
     }
 
@@ -957,7 +966,8 @@ L<PAR>, L<PAR::Dist>, L<parl>, L<pp>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>cpan@audreyt.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>,
+Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
 L<http://par.perl.org/> is the official PAR website.  You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
@@ -967,8 +977,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004, 2005, 2006 by Audrey Tang
-E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 Neither this program nor the associated L<parl> program impose any
 licensing restrictions on files generated by their execution, in
